@@ -48,6 +48,7 @@ public class OSInfo {
     public static final String IBMZ_64 = "s390x";
     public static final String AARCH_64 = "aarch64";
     public static final String RISCV_64 = "riscv64";
+    public static final String LOONGARCH_64 = "loongarch64";
 
     static {
         // x86 mappings
@@ -97,6 +98,9 @@ public class OSInfo {
 
         // RISC-V mappings
         archMapping.put(RISCV_64, RISCV_64);
+
+        // LoongArch64 mappings
+        archMapping.put(LOONGARCH_64, LOONGARCH_64);
     }
 
     public static void main(String[] args) {
